@@ -22,15 +22,14 @@ func (h HexBytes) MarshalText() ([]byte, error) {
 	return result, nil
 }
 
-// UnmarshalText implements encoding.TextMarshaler.UnmarshalText.
+// UnmarshalText implements encoding.TextUnmarshaler.UnmarshalText.
 func (h *HexBytes) UnmarshalText(text []byte) error {
 	if len(text) == 0 {
 		*h = nil
 		return nil
 	}
 	result := make([]byte, hex.DecodedLen(len(text)))
-	_, err := hex.Decode(result, text)
-	if err != nil {
+	if _, err := hex.Decode(result, text); err != nil {
 		return err
 	}
 	*h = result
