@@ -58,35 +58,22 @@ func (c *Config) addInteractiveTemplateFuncFlags(flags *pflag.FlagSet) {
 
 func (c *Config) promptBoolInteractiveTemplateFunc(prompt string, args ...bool) bool {
 	if len(args) > 1 {
-		err := fmt.Errorf("want 1 or 2 arguments, got %d", len(args)+1)
-		panic(err)
+		panic(fmt.Errorf("want 1 or 2 arguments, got %d", len(args)+1))
 	}
 
 	if valueStr, ok := c.interactiveTemplateFuncs.promptBool[prompt]; ok {
-		value, err := chezmoi.ParseBool(valueStr)
-		if err != nil {
-			panic(err)
-		}
-		return value
+		return mustValue(chezmoi.ParseBool(valueStr))
 	}
 
-	value, err := c.promptBool(prompt, args...)
-	if err != nil {
-		panic(err)
-	}
-	return value
+	return mustValue(c.promptBool(prompt, args...))
 }
 
 func (c *Config) promptBoolOnceInteractiveTemplateFunc(m map[string]any, path any, prompt string, args ...bool) bool {
 	if len(args) > 1 {
-		err := fmt.Errorf("want 3 or 4 arguments, got %d", len(args)+2)
-		panic(err)
+		panic(fmt.Errorf("want 3 or 4 arguments, got %d", len(args)+2))
 	}
 
-	nestedMap, lastKey, err := nestedMapAtPath(m, path)
-	if err != nil {
-		panic(err)
-	}
+	nestedMap, lastKey := mustValues(nestedMapAtPath(m, path))
 	if !c.interactiveTemplateFuncs.forcePromptOnce {
 		if value, ok := nestedMap[lastKey]; ok {
 			switch value := value.(type) {
@@ -105,24 +92,15 @@ func (c *Config) promptBoolOnceInteractiveTemplateFunc(m map[string]any, path an
 
 func (c *Config) promptChoiceInteractiveTemplateFunc(prompt string, choices any, args ...string) string {
 	if len(args) > 1 {
-		err := fmt.Errorf("want 2 or 3 arguments, got %d", len(args)+2)
-		panic(err)
+		panic(fmt.Errorf("want 2 or 3 arguments, got %d", len(args)+2))
 	}
 
 	if valueStr, ok := c.interactiveTemplateFuncs.promptChoice[prompt]; ok {
 		return valueStr
 	}
 
-	choiceStrs, err := anyToStringSlice(choices)
-	if err != nil {
-		panic(err)
-	}
-
-	value, err := c.promptChoice(prompt, choiceStrs, args...)
-	if err != nil {
-		panic(err)
-	}
-	return value
+	choiceStrs := mustValue(anyToStringSlice(choices))
+	return mustValue(c.promptChoice(prompt, choiceStrs, args...))
 }
 
 func (c *Config) promptChoiceOnceInteractiveTemplateFunc(
@@ -133,14 +111,10 @@ func (c *Config) promptChoiceOnceInteractiveTemplateFunc(
 	args ...string,
 ) string {
 	if len(args) > 1 {
-		err := fmt.Errorf("want 4 or 5 arguments, got %d", len(args)+4)
-		panic(err)
+		panic(fmt.Errorf("want 4 or 5 arguments, got %d", len(args)+4))
 	}
 
-	nestedMap, lastKey, err := nestedMapAtPath(m, path)
-	if err != nil {
-		panic(err)
-	}
+	nestedMap, lastKey := mustValues(nestedMapAtPath(m, path))
 	if !c.interactiveTemplateFuncs.forcePromptOnce {
 		if value, ok := nestedMap[lastKey]; ok {
 			if valueStr, ok := value.(string); ok {
@@ -154,31 +128,22 @@ func (c *Config) promptChoiceOnceInteractiveTemplateFunc(
 
 func (c *Config) promptIntInteractiveTemplateFunc(prompt string, args ...int64) int64 {
 	if len(args) > 1 {
-		err := fmt.Errorf("want 1 or 2 arguments, got %d", len(args)+1)
-		panic(err)
+		panic(fmt.Errorf("want 1 or 2 arguments, got %d", len(args)+1))
 	}
 
 	if value, ok := c.interactiveTemplateFuncs.promptInt[prompt]; ok {
 		return int64(value)
 	}
 
-	value, err := c.promptInt(prompt, args...)
-	if err != nil {
-		panic(err)
-	}
-	return value
+	return mustValue(c.promptInt(prompt, args...))
 }
 
 func (c *Config) promptIntOnceInteractiveTemplateFunc(m map[string]any, path any, prompt string, args ...int64) int64 {
 	if len(args) > 1 {
-		err := fmt.Errorf("want 2 or 3 arguments, got %d", len(args)+2)
-		panic(err)
+		panic(fmt.Errorf("want 2 or 3 arguments, got %d", len(args)+2))
 	}
 
-	nestedMap, lastKey, err := nestedMapAtPath(m, path)
-	if err != nil {
-		panic(err)
-	}
+	nestedMap, lastKey := mustValues(nestedMapAtPath(m, path))
 	if !c.interactiveTemplateFuncs.forcePromptOnce {
 		if value, ok := nestedMap[lastKey]; ok {
 			if intValue, ok := value.(int64); ok {
@@ -192,31 +157,22 @@ func (c *Config) promptIntOnceInteractiveTemplateFunc(m map[string]any, path any
 
 func (c *Config) promptStringInteractiveTemplateFunc(prompt string, args ...string) string {
 	if len(args) > 1 {
-		err := fmt.Errorf("want 1 or 2 arguments, got %d", len(args)+1)
-		panic(err)
+		panic(fmt.Errorf("want 1 or 2 arguments, got %d", len(args)+1))
 	}
 
 	if value, ok := c.interactiveTemplateFuncs.promptString[prompt]; ok {
 		return value
 	}
 
-	value, err := c.promptString(prompt, args...)
-	if err != nil {
-		panic(err)
-	}
-	return value
+	return mustValue(c.promptString(prompt, args...))
 }
 
 func (c *Config) promptStringOnceInteractiveTemplateFunc(m map[string]any, path any, prompt string, args ...string) string {
 	if len(args) > 1 {
-		err := fmt.Errorf("want 2 or 3 arguments, got %d", len(args)+2)
-		panic(err)
+		panic(fmt.Errorf("want 2 or 3 arguments, got %d", len(args)+2))
 	}
 
-	nestedMap, lastKey, err := nestedMapAtPath(m, path)
-	if err != nil {
-		panic(err)
-	}
+	nestedMap, lastKey := mustValues(nestedMapAtPath(m, path))
 	if !c.interactiveTemplateFuncs.forcePromptOnce {
 		if value, ok := nestedMap[lastKey]; ok {
 			if stringValue, ok := value.(string); ok {
